@@ -3,12 +3,34 @@ from __future__ import annotations
 import os
 import pretty_errors
 import rich
+from typing import Literal, Tuple
 
 
 class Cli:
     def __init__(self):
         ...
 
+    def deduplicate(self, in_file: str, out_file: str, target_col='data', chunk_size = 200, threshold=None, method:Literal["edit", "rouge", "bleu"]='edit', use_jieba=False):
+        if method == "edit":
+            from .nlp.deduplicate import EditSimilarity
+            simi = EditSimilarity()
+            if threshold is None:
+                threshold = 0.7
+        elif method == "rouge":
+            from .nlp.deduplicate import RougeSimilarity
+            simi = RougeSimilarity(use_jieba=use_jieba)
+            if threshold is None:
+                threshold = 0.5
+        elif method == "bleu":
+            from .nlp.deduplicate import BleuSimilarity
+            simi = BleuSimilarity(use_jieba=use_jieba)
+            if threshold is None:
+                threshold = 0.5
+        else:
+            raise ValueError(f"method should be one of 'edit', 'rouge', 'bleu', but got {method}")
+        simi.load_data(in_file, target_col=target_col)
+        simi.deduplicate(chunk_size=chunk_size, save_to_file=out_file, threshold=threshold)
+
     @staticmethod
     def post(url: str, data: dict, concurrent: int = 10, ):
         import asyncio
@@ -33,9 +55,16 @@ class Cli:
         return timer(dt)
 
     @staticmethod
-    def auto_commit(repo_path='.', remote_repo_name: str | None = None):
+    def auto_commit(
+            repo_path='.',
+            remote_repo_name: str | None = None,
+            name="K.Y.Bot", email="beidongjiedeguang@gmail.com",
+            interval=60
+    ):
         from .git.monitor import start_watcher
-        start_watcher(repo_path, remote_repo_name)
+        start_watcher(repo_path=repo_path, remote_repo_name=remote_repo_name,
+                      name=name, email=email,
+                      interval=interval)
 
     @staticmethod
     def install_node(version=16):
@@ -88,9 +117,9 @@ class Cli:
         return start_server(**kwargs)
 
     @staticmethod
-    def kill(*ports: int, view=False):
+    def kill(ports: Tuple[int], view=False):
         from .multiprocess import kill
-        return kill(*ports, view)
+        return kill(ports, view)
 
     @staticmethod
     def clone(url: str, save_path=None, branch=None, proxy=False):
